.\" @project      The CERN Tape Archive (CTA)
.\" @copyright    Copyright © 2002-2022 CERN
.\" @license      This program is free software, distributed under the terms of the GNU General Public
.\"               Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING". You can
.\"               redistribute it and/or modify it under the terms of the GPL Version 3, or (at your
.\"               option) any later version.
.\"
.\"               This program is distributed in the hope that it will be useful, but WITHOUT ANY
.\"               WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
.\"               PARTICULAR PURPOSE. See the GNU General Public License for more details.
.\"
.\"               In applying this licence, CERN does not waive the privileges and immunities
.\"               granted to it by virtue of its status as an Intergovernmental Organization or
.\"               submit itself to any jurisdiction.
.TH RMC_READ_ELEM_STATUS "3castor" "$Date: 2002/12/06 15:58:33 $" CASTOR "rmc Library Functions"
.SH NAME
rmc_read_elem_status \- send a request to the Remote Media Changer daemon to read element(s) status in the robot
.SH SYNOPSIS
.B #include <sys/types.h>
.br
\fB#include "rmc_api.h"\fR
.sp
.BI "int rmc_read_elem_status (char *" server ,
.BI "char *" smc_ldr ,
.BI "int " type ,
.BI "int " startaddr ,
.BI "int " nbelem ,
.BI "struct smc_element_info *" element_info );
.SH DESCRIPTION
.B rmc_read_elem_status
asks the Remote Media Changer server running on
.I server
and connected to the picker
.I smc_ldr
to get the status of the elements of type
.IR type .
.TP
.I server
specifies the Remote Media Changer to be contacted.
.TP
.I smc_ldr
is the picker device as defined in /dev.
.TP
.I type
gives the element type: 0 means all element types, 1 corresponds to the hand,
2 to the storage cells, 3 to the import/export door (CAP) and 4 to the drives.
.TP
.I startaddr
specifies the lowest element address to be searched.
.TP
.I nbelem
gives the maximum number of entries to be returned
.TP
.I element_info
gives the address of the buffer allocated by the calling program to receive the
reply.
.PP
.nf
.ft CW
struct smc_element_info {
        int element_address;
        int element_type;
        int state;		/* element descriptor byte 2 */
        unsigned char asc;
        unsigned char ascq;
        int flags;		/* element descriptor byte 9 */
        int source_address;
        char name[9];
};
.ft
.fi
.SH RETURN VALUE
This routine returns 0 if the operation was successful or -1 if the operation
failed. In the latter case,
.B serrno
is set appropriately.
.SH ERRORS
.TP 1.2i
.B SECOMERR
Communication error.
.TP
.B ERMCUNREC
Unknown host or invalid loader.
.TP
.B ERMCFASTR
Unit attention.
.TP
.B ERMCOMSGR
Hardware error.
.SH SEE ALSO
.BR rmc_get_geometry(3) ,
.B smc(1)
.SH AUTHOR
\fBCASTOR\fP Team <castor.support@cern.ch>
